==> monodevelop_0.9.orig.tar.gz: monodevelop-0.9/Core/src/MonoDevelop.Core/MonoDevelop.Core.AddIns/ExecutionHandlerCodon.cs <==
//
// ExecutionHandlerCodon.cs
//
// Author:
//   Lluis Sanchez Gual
//

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.Collections;

using MonoDevelop.Core.AddIns;
using MonoDevelop.Core;
using MonoDevelop.Core.Execution;

namespace MonoDevelop.Core.AddIns
{
	[CodonNameAttribute ("ExecutionHandler")]
	class ExecutionHandlerCodon : AbstractCodon
	{
		IExecutionHandler handler;
		
		[XmlMemberAttribute ("platform", IsRequired = true)]
		string platform = null;
		
		public IExecutionHandler ExecutionHandler {
			get { return handler; }
		}
		
		public string Platform {
			get { return platform; }
		}
		
		public override object BuildItem (object owner, ArrayList subItems, ConditionCollection conditions)
		{
			handler = (IExecutionHandler) AddIn.CreateObject (Class);
			return this;
		}
	}
}

==> monodevelop_0.12.orig.tar.gz: monodevelop-0.12/Core/src/MonoDevelop.Core/MonoDevelop.Core.AddIns/ExecutionHandlerCodon.cs <==
//
// ExecutionHandlerCodon.cs
//
// Author:
//   Lluis Sanchez Gual
//

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.Collections;
using System.ComponentModel;

using MonoDevelop.Core.AddIns;
using MonoDevelop.Core;
using MonoDevelop.Core.Execution;

namespace MonoDevelop.Core.AddIns
{
	[CodonNameAttribute ("ExecutionHandler")]
	[Description ("Registers an IExecutionHandler type.")]
	class ExecutionHandlerCodon : AbstractCodon
	{
		IExecutionHandler handler;
		
		[XmlMemberAttribute ("platform", IsRequired = true)]
		[Description ("Platform supported by this execution handler. The core platforms are Mono, Mint and Native. Add-ins may define additional platforms.")]
		string platform = null;
		
		public IExecutionHandler ExecutionHandler {
			get { return handler; }
		}
		
		public string Platform {
			get { return platform; }
		}
		
		public override object BuildItem (object owner, ArrayList subItems, ConditionCollection conditions)
		{
			handler = (IExecutionHandler) AddIn.CreateObject (Class);
			return this;
		}
	}
}
